@@ -1,5 +1,6 @@
 /*
  *   Copyright (C) 2009 Petri Damstén <damu@iki.fi>
+ *   Copyright (C) 2014 John Layt <jlayt@kde.org>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -20,12 +21,17 @@
 #ifndef FUELEFFICIENCY_P_H
 #define FUELEFFICIENCY_P_H
 
-#include "unitcategory.h"
+#include "unitcategory_p.h"
 
-class FuelEfficiency : public KUnitConversion::UnitCategory
+namespace KUnitConversion
+{
+
+class FuelEfficiency : public CustomCategory
 {
 public:
     FuelEfficiency();
 };
 
+} // KUnitConversion namespace
+
 #endif
